#!/usr/bin/sh
# SPDX-License-Identifier: MIT

set -eu -o pipefail

# Test if the basic identity is not used
if ! rpm --quiet --query fedora-asahi-remix-release-identity-basic; then
    systemctl disable asahi-branding-fixup.timer
    exit 0
fi

# Check if network connectivity is present
CONNECTION_STATUS="$(curl -s http://fedoraproject.org/static/hotspot.txt)"
if [ "${CONNECTION_STATUS}" != "OK" ]; then
    echo "No internet connectivity, exiting..."
    exit 0
fi

# Ensure the correct identity packages are installed

if rpm --quiet --query fedora-asahi-remix-release-kde; then
    dnf --assumeyes install --allowerasing fedora-asahi-remix-release-identity-kde
    systemctl disable asahi-branding-fixup.timer
    exit 0
fi

if rpm --quiet --query fedora-asahi-remix-release-workstation; then
    dnf --assumeyes install --allowerasing fedora-asahi-remix-release-identity-workstation
    systemctl disable asahi-branding-fixup.timer
    exit 0
fi

if rpm --quiet --query fedora-asahi-remix-release-server; then
    dnf --assumeyes install --allowerasing fedora-asahi-remix-release-identity-server
    systemctl disable asahi-branding-fixup.timer
    exit 0
fi

# Stop future runs of the service
systemctl disable asahi-branding-fixup.timer

exit 0
